pub enum IncludeHistory {
Yes,
No,
}Expand description
Whether to include the historical dates in the future dataframe for predictions.
Variants
Yes
Include the historical dates in the future dataframe.
No
Do not include the historical dates in the future data frame.