pub enum SeasonalityOption {
Auto,
Manual(bool),
Fourier(NonZeroU32),
}Expand description
Define whether to include a specific seasonality, and how it should be specified.
Variants
Auto
Automatically determine whether to include this seasonality.
Yearly seasonality is automatically included if there is >=2 years of history.
Weekly seasonality is automatically included if there is >=2 weeks of history, and the spacing between the dates in the data is <7 days.
Daily seasonality is automatically included if there is >=2 days of history, and the spacing between the dates in the data is <1 day.
Manual(bool)
Manually specify whether to include this seasonality.
Fourier(NonZeroU32)
Enable this seasonality and use the provided number of Fourier terms.