pub struct Data {}Expand description
Data for the Prophet model.
Fields
T: i32Number of time periods.
y: Vec<f64>Time series, length n.
t: Vec<f64>Time, length n.
cap: Vec<f64>Capacities for logistic trend, length n.
S: i32Number of changepoints.
t_change: Vec<f64>Times of trend changepoints, length s.
trend_indicator: TrendIndicatorThe type of trend to use.
K: i32Number of regressors. Must be greater than or equal to 1.
s_a: Vec<i32>Indicator of additive features, length k.
s_m: Vec<i32>Indicator of multiplicative features, length k.
X: Vec<f64>Regressors, shape (n, k).
This is stored as a Vec<f64> rather than a nested Vec<Vec<f64>>
because passing such a struct by reference is tricky in Rust, since
it can’t be dereferenced to a &[&[f64]] (which would be ideal).
However, when serialized to JSON, it is converted to a nested array of arrays, which is what cmdstan expects.
sigmas: Vec<PositiveFloat>Scale on seasonality prior.
tau: PositiveFloatScale on changepoints prior. Must be greater than 0.