pub struct OptimizeOpts {Show 13 fields
pub algorithm: Option<Algorithm>,
pub seed: Option<u32>,
pub chain: Option<u32>,
pub init_alpha: Option<f64>,
pub tol_obj: Option<f64>,
pub tol_rel_obj: Option<f64>,
pub tol_grad: Option<f64>,
pub tol_rel_grad: Option<f64>,
pub tol_param: Option<f64>,
pub history_size: Option<u32>,
pub iter: Option<u32>,
pub jacobian: Option<bool>,
pub refresh: Option<u32>,
}Expand description
Arguments for optimization.
Fields
algorithm: Option<Algorithm>Algorithm to use.
seed: Option<u32>The random seed to use for the optimization.
chain: Option<u32>The chain id to advance the PRNG.
init_alpha: Option<f64>Line search step size for first iteration.
tol_obj: Option<f64>Convergence tolerance on changes in objective function value.
tol_rel_obj: Option<f64>Convergence tolerance on relative changes in objective function value.
tol_grad: Option<f64>Convergence tolerance on the norm of the gradient.
tol_rel_grad: Option<f64>Convergence tolerance on the relative norm of the gradient.
tol_param: Option<f64>Convergence tolerance on changes in parameter value.
history_size: Option<u32>Size of the history for LBFGS Hessian approximation. The value should be less than the dimensionality of the parameter space. 5-10 usually sufficient.
iter: Option<u32>Total number of iterations.
jacobian: Option<bool>When true, use the Jacobian matrix to approximate the Hessian.
Default is false.
refresh: Option<u32>How frequently to emit convergence statistics, in number of iterations.