PredictionData

Struct PredictionData 

pub struct PredictionData {
    pub n: usize,
    pub ds: Vec<TimestampSeconds>,
    pub cap: Option<Vec<f64>>,
    pub floor: Option<Vec<f64>>,
    pub seasonality_conditions: HashMap<String, Vec<bool>>,
    pub x: HashMap<String, Vec<f64>>,
}
The data needed to predict with a Prophet model.

The structure of the prediction data must be the same as the training data used to train the model, with the exception of y (which is being predicted).

That is, if your model used certain seasonality conditions or regressors, you must include them in the prediction data.

Fields

n: usize

The number of time points in the prediction data.

ds: Vec<TimestampSeconds>

The timestamps of the time series.

These should be in seconds since the epoch.

cap: Option<Vec<f64>>

Optionally, an upper bound (cap) on the values of the time series.

Only used if the model’s growth type is logistic.

floor: Option<Vec<f64>>

Optionally, a lower bound (floor) on the values of the time series.

Only used if the model’s growth type is logistic.

seasonality_conditions: HashMap<String, Vec<bool>>

Indicator variables for conditional seasonalities.

The keys of the map are the names of the seasonality components, and the values are boolean arrays of length n where true indicates that the component is active for the corresponding time point.

x: HashMap<String, Vec<f64>>

Exogenous regressors.

The keys of the map are the names of the regressors, and the values are arrays of length n containing the regressor values for each time point.

Implementations

Source

impl PredictionData

pub fn new(ds: Vec<TimestampSeconds>) -> Self

Create some data to be used for predictions.

Predictions will be made for each of the dates in ds.

pub fn with_cap(self, cap: Vec<f64>) -> Result<Self, Error>

Add the cap for logistic growth.

Errors

Returns an error if the lengths of ds and cap are not equal.

pub fn with_floor(self, floor: Vec<f64>) -> Result<Self, Error>

Add the floor for logistic growth.

Errors

Returns an error if the lengths of ds and floor are not equal.

pub fn with_seasonality_conditions( self, seasonality_conditions: HashMap<String, Vec<bool>>, ) -> Result<Self, Error>

Add condition columns for conditional seasonalities.

Errors

Returns an error if the lengths of any of the seasonality conditions are not equal to the length of ds.

pub fn with_regressors( self, x: HashMap<String, Vec<f64>>, ) -> Result<Self, Error>

Add regressors.

Errors

Returns an error if the lengths of any of the regressors are not equal to the length of ds.