Prophet

Struct Prophet 

pub struct Prophet<O> { /* private fields */ }
The Prophet time series forecasting model.

Implementations

Source

impl<O> Prophet<O>

pub fn new(opts: ProphetOptions, optimizer: O) -> Self

Create a new Prophet model with the given options and optimizer.

pub fn add_seasonality( &mut self, name: String, seasonality: Seasonality, ) -> Result<&mut Self, Error>

Add a custom seasonality to the model.

pub fn add_regressor(&mut self, name: String, regressor: Regressor) -> &mut Self

Add a regressor to the model.

pub fn is_fitted(&self) -> bool

Return true if the model has been fit, or false if not.

pub fn predict( &self, data: impl Into<Option<PredictionData>>, ) -> Result<Predictions, Error>

Predict using the Prophet model.

Errors

Returns an error if the model has not been fit.

pub fn make_future_dataframe( &self, horizon: NonZeroU32, include_history: IncludeHistory, ) -> Result<PredictionData, Error>

Create dates to use for predictions.

Parameters
  • horizon: The number of days to predict forward.
  • include_history: Whether to include the historical dates in the future dataframe.
Errors

Returns an error if the model has not been fit.

pub fn opts(&self) -> &ProphetOptions

Get a reference to the Prophet options.

pub fn opts_mut(&mut self) -> &mut ProphetOptions

Get a mutable reference to the Prophet options.

pub fn set_interval_width(&mut self, interval_width: IntervalWidth)

Set the width of the uncertainty intervals.

The interval width does not affect training, only predictions, so this can be called after fitting the model to obtain predictions with different levels of uncertainty.

Source

impl<O: Optimizer + 'static> Prophet<O>

pub fn into_forecaster( self, data: TrainingData, optimize_opts: OptimizeOpts, ) -> ProphetForecaster

Create a new ProphetForecaster from this Prophet model.

This requires the data and optimize options to be provided and sets up a ProphetForecaster ready to be used with the augurs_forecaster crate.

Source

impl<O: Optimizer> Prophet<O>

pub fn fit( &mut self, data: TrainingData, opts: OptimizeOpts, ) -> Result<(), Error>

Fit the Prophet model to some training data.