ProphetOptions

Struct ProphetOptions 

pub struct ProphetOptions {
Show 17 fields pub growth: GrowthType, pub changepoints: Option<Vec<TimestampSeconds>>, pub n_changepoints: u32, pub changepoint_range: PositiveFloat, pub yearly_seasonality: SeasonalityOption, pub weekly_seasonality: SeasonalityOption, pub daily_seasonality: SeasonalityOption, pub seasonality_mode: FeatureMode, pub seasonality_prior_scale: PositiveFloat, pub changepoint_prior_scale: PositiveFloat, pub estimation: EstimationMode, pub interval_width: IntervalWidth, pub uncertainty_samples: u32, pub scaling: Scaling, pub holidays: HashMap<String, Holiday>, pub holidays_prior_scale: PositiveFloat, pub holidays_mode: Option<FeatureMode>,
}
Options for Prophet, after applying defaults.

Fields

growth: GrowthType

The type of growth (trend) to use.

Defaults to GrowthType::Linear.

changepoints: Option<Vec<TimestampSeconds>>

An optional list of changepoints.

If not provided, changepoints will be automatically selected.

n_changepoints: u32

The number of potential changepoints to include.

Not used if changepoints is provided.

If provided and changepoints is not provided, then n_changepoints potential changepoints will be selected uniformly from the first changepoint_range proportion of the history.

Defaults to 25.

changepoint_range: PositiveFloat

The proportion of the history to consider for potential changepoints.

Not used if changepoints is provided.

Defaults to 0.8 for the first 80% of the data.

yearly_seasonality: SeasonalityOption

How to fit yearly seasonality.

Defaults to SeasonalityOption::Auto.

weekly_seasonality: SeasonalityOption

How to fit weekly seasonality.

Defaults to SeasonalityOption::Auto.

daily_seasonality: SeasonalityOption

How to fit daily seasonality.

Defaults to SeasonalityOption::Auto.

seasonality_mode: FeatureMode

How to model seasonality.

Defaults to FeatureMode::Additive.

seasonality_prior_scale: PositiveFloat

The prior scale for seasonality.

This modulates the strength of seasonality, with larger values allowing the model to fit larger seasonal fluctuations and smaller values dampening the seasonality.

Can be specified for individual seasonalities using Prophet::add_seasonality.

Defaults to 10.0.

changepoint_prior_scale: PositiveFloat

The prior scale for changepoints.

This modulates the flexibility of the automatic changepoint selection. Large values will allow many changepoints, while small values will allow few changepoints.

Defaults to 0.05.

estimation: EstimationMode

How to perform parameter estimation.

When EstimationMode::Mle or EstimationMode::Map are used then no MCMC samples are taken.

Defaults to EstimationMode::Mle.

interval_width: IntervalWidth

The width of the uncertainty intervals.

Must be between 0.0 and 1.0. Common values are 0.8 (80%), 0.9 (90%) and 0.95 (95%).

Defaults to 0.8 for 80% intervals.

uncertainty_samples: u32

The number of simulated draws used to estimate uncertainty intervals.

Setting this value to 0 will disable uncertainty estimation and speed up the calculation.

Defaults to 1000.

scaling: Scaling

How to scale the data prior to fitting the model.

Defaults to Scaling::AbsMax.

holidays: HashMap<String, Holiday>

Holidays to include in the model.

holidays_prior_scale: PositiveFloat

Prior scale for holidays.

This parameter modulates the strength of the holiday components model, unless overridden in each individual holiday’s input.

Defaults to 100.0.

holidays_mode: Option<FeatureMode>

How to model holidays.

Defaults to the same value as ProphetOptions::seasonality_mode.