pub struct Regressor { /* private fields */ }Expand description
An exogynous regressor.
By default, regressors inherit the holidays_prior_scale
configured on the Prophet model as their prior scale.
Implementations
Sourceimpl Regressor
impl Regressor
Sourcepub fn multiplicative() -> Self
pub fn multiplicative() -> Self
Create a new multiplicative regressor.
Sourcepub fn with_prior_scale(self, prior_scale: PositiveFloat) -> Self
pub fn with_prior_scale(self, prior_scale: PositiveFloat) -> Self
Set the prior scale of this regressor.
By default, regressors inherit the holidays_prior_scale
configured on the Prophet model as their prior scale.
Sourcepub fn with_standardize(self, standardize: Standardize) -> Self
pub fn with_standardize(self, standardize: Standardize) -> Self
Set whether to standardize this regressor.