Seasonality

Struct Seasonality 

pub struct Seasonality { /* private fields */ }
A seasonality to include in the model.

Implementations

Source

impl Seasonality

pub fn new(period: PositiveFloat, fourier_order: NonZeroU32) -> Self

Create a new Seasonality with the given period and fourier order.

By default, the prior scale and mode will be inherited from the Prophet model config, and the seasonality is assumed to be non-conditional.

pub fn with_prior_scale(self, prior_scale: PositiveFloat) -> Self

Set the prior scale of this seasonality.

By default, seasonalities inherit the prior scale configured on the Prophet model; this allows the prior scale to be customised for each seasonality.

pub fn with_mode(self, mode: FeatureMode) -> Self

Set the mode of this seasonality.

By default, seasonalities inherit the mode configured on the Prophet model; this allows the mode to be customised for each seasonality.

pub fn with_condition(self, condition_name: String) -> Self

Set this seasonality as conditional.

A column with the provided condition name must be present in the data passed to Prophet otherwise training will fail. This can be added with TrainingData::with_seasonality_conditions.