TrainingData

Struct TrainingData 

pub struct TrainingData { /* private fields */ }
The data needed to train a Prophet model.

Create a TrainingData object with the new method, which takes a vector of dates and a vector of values.

Optionally, you can add seasonality conditions, regressors, floor and cap columns.

Implementations

Source

impl TrainingData

pub fn new(ds: Vec<TimestampSeconds>, y: Vec<f64>) -> Result<Self, Error>

Create some input data for Prophet.

Errors

Returns an error if the lengths of ds and y differ.

pub fn with_cap(self, cap: Vec<f64>) -> Result<Self, Error>

Add the cap for logistic growth.

Errors

Returns an error if the lengths of ds and cap differ.

pub fn with_floor(self, floor: Vec<f64>) -> Result<Self, Error>

Add the floor for logistic growth.

Errors

Returns an error if the lengths of ds and floor differ.

pub fn with_seasonality_conditions( self, seasonality_conditions: HashMap<String, Vec<bool>>, ) -> Result<Self, Error>

Add condition columns for conditional seasonalities.

Errors

Returns an error if the lengths of ds and any of the seasonality condition columns differ.

pub fn with_regressors( self, x: HashMap<String, Vec<f64>>, ) -> Result<Self, Error>

Add regressors.

Errors

Returns an error if the lengths of ds and any of the regressor columns differ.