#[non_exhaustive]pub enum Error {
Show 18 variants
MismatchedLengths {
a: usize,
b: usize,
a_name: String,
b_name: String,
},
NotEnoughData,
OptimizationFailed(String),
InvalidIntervalWidth(f64),
TooManyDataPoints(usize),
TimestampsAreConstant(TimestampSeconds),
DuplicateSeasonality(String),
InfiniteValue {
column: String,
},
NaNValue {
column: String,
},
MissingRegressor(String),
MissingSeasonalityCondition(String),
AbsMaxScalingFailed,
MissingCap,
MissingFloor,
CapNotGreaterThanFloor,
ChangepointsOutOfRange,
ModelNotFit,
UnableToInferFrequency(Vec<TimestampSeconds>),
}Expand description
Errors that can occur when using the Prophet forecasting algorithm.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
MismatchedLengths
The data provided had mismatched column lengths.
Fields
NotEnoughData
Not enough data was provided to fit the model.
OptimizationFailed(String)
Optimization failed for some reason.
InvalidIntervalWidth(f64)
An invalid interval width was passed.
The interval width must be between 0.0 and 1.0.
TooManyDataPoints(usize)
Too many data points were provided, overflowing an i32.
TimestampsAreConstant(TimestampSeconds)
The timestamps provided are constant.
DuplicateSeasonality(String)
The same seasonality was added to the model twice.
InfiniteValue
A column contained an infinite value.
NaNValue
A column contained a NaN value.
MissingRegressor(String)
A regressor was added to the model but missing from the data.
MissingSeasonalityCondition(String)
A seasonality in the model was marked as conditional but the condition column was missing from the data.
AbsMaxScalingFailed
AbsMax scaling failed because the min and max were the same.
MissingCap
The cap column for logistic growth was missing.
MissingFloor
The floor column for logistic growth was missing.
CapNotGreaterThanFloor
The cap was not always greater than the floor.
ChangepointsOutOfRange
One or more of the provided changepoints were out of the range of the training data.
ModelNotFit
The Prophet model has not yet been fit.
Fit the model first using Prophet::fit.
UnableToInferFrequency(Vec<TimestampSeconds>)
It was not possible to infer the frequency of the dates.
This can happen if the dates are not evenly spaced, and there is no frequency that appears more often than others.