pub struct OptProphetOptions {Show 17 fields
pub growth: Option<GrowthType>,
pub changepoints: Option<Vec<TimestampSeconds>>,
pub n_changepoints: Option<u32>,
pub changepoint_range: Option<PositiveFloat>,
pub yearly_seasonality: Option<SeasonalityOption>,
pub weekly_seasonality: Option<SeasonalityOption>,
pub daily_seasonality: Option<SeasonalityOption>,
pub seasonality_mode: Option<FeatureMode>,
pub seasonality_prior_scale: Option<PositiveFloat>,
pub changepoint_prior_scale: Option<PositiveFloat>,
pub estimation: Option<EstimationMode>,
pub interval_width: Option<IntervalWidth>,
pub uncertainty_samples: Option<u32>,
pub scaling: Option<Scaling>,
pub holidays: Option<HashMap<String, Holiday>>,
pub holidays_prior_scale: Option<PositiveFloat>,
pub holidays_mode: Option<FeatureMode>,
}Expand description
Optional version of Prophet’s options, before applying any defaults.
Fields
growth: Option<GrowthType>The type of growth (trend) to use.
changepoints: Option<Vec<TimestampSeconds>>An optional list of changepoints.
If not provided, changepoints will be automatically selected.
n_changepoints: Option<u32>The number of potential changepoints to include.
Not used if changepoints is provided.
If provided and changepoints is not provided, then
n_changepoints potential changepoints will be selected
uniformly from the first changepoint_range proportion of
the history.
changepoint_range: Option<PositiveFloat>The proportion of the history to consider for potential changepoints.
Not used if changepoints is provided.
yearly_seasonality: Option<SeasonalityOption>How to fit yearly seasonality.
weekly_seasonality: Option<SeasonalityOption>How to fit weekly seasonality.
daily_seasonality: Option<SeasonalityOption>How to fit daily seasonality.
seasonality_mode: Option<FeatureMode>How to model seasonality.
seasonality_prior_scale: Option<PositiveFloat>The prior scale for seasonality.
This modulates the strength of seasonality, with larger values allowing the model to fit larger seasonal fluctuations and smaller values dampening the seasonality.
Can be specified for individual seasonalities
using Prophet::add_seasonality.
changepoint_prior_scale: Option<PositiveFloat>The prior scale for changepoints.
This modulates the flexibility of the automatic changepoint selection. Large values will allow many changepoints, while small values will allow few changepoints.
estimation: Option<EstimationMode>How to perform parameter estimation.
When EstimationMode::Mle or EstimationMode::Map
are used then no MCMC samples are taken.
interval_width: Option<IntervalWidth>The width of the uncertainty intervals.
Must be between 0.0 and 1.0. Common values are
0.8 (80%), 0.9 (90%) and 0.95 (95%).
uncertainty_samples: Option<u32>The number of simulated draws used to estimate uncertainty intervals.
Setting this value to 0 will disable uncertainty
estimation and speed up the calculation.
scaling: Option<Scaling>How to scale the data prior to fitting the model.
holidays: Option<HashMap<String, Holiday>>Holidays to include in the model.
holidays_prior_scale: Option<PositiveFloat>Prior scale for holidays.
This parameter modulates the strength of the holiday components model, unless overridden in each individual holiday’s input.
holidays_mode: Option<FeatureMode>How to model holidays.