pub struct PredictionData {
pub n: usize,
pub ds: Vec<TimestampSeconds>,
pub cap: Option<Vec<f64>>,
pub floor: Option<Vec<f64>>,
pub seasonality_conditions: HashMap<String, Vec<bool>>,
pub x: HashMap<String, Vec<f64>>,
}Expand description
The data needed to predict with a Prophet model.
The structure of the prediction data must be the same as the
training data used to train the model, with the exception of
y (which is being predicted).
That is, if your model used certain seasonality conditions or regressors, you must include them in the prediction data.
Fields
n: usizeThe number of time points in the prediction data.
ds: Vec<TimestampSeconds>The timestamps of the time series.
These should be in seconds since the epoch.
cap: Option<Vec<f64>>Optionally, an upper bound (cap) on the values of the time series.
Only used if the model’s growth type is logistic.
floor: Option<Vec<f64>>Optionally, a lower bound (floor) on the values of the time series.
Only used if the model’s growth type is logistic.
seasonality_conditions: HashMap<String, Vec<bool>>Indicator variables for conditional seasonalities.
The keys of the map are the names of the seasonality components,
and the values are boolean arrays of length n where true indicates
that the component is active for the corresponding time point.
x: HashMap<String, Vec<f64>>Exogenous regressors.
The keys of the map are the names of the regressors,
and the values are arrays of length n containing the regressor values
for each time point.
Implementations
Sourceimpl PredictionData
impl PredictionData
Sourcepub fn new(ds: Vec<TimestampSeconds>) -> Self
pub fn new(ds: Vec<TimestampSeconds>) -> Self
Create some data to be used for predictions.
Predictions will be made for each of the dates in ds.
Sourcepub fn with_cap(self, cap: Vec<f64>) -> Result<Self, Error>
pub fn with_cap(self, cap: Vec<f64>) -> Result<Self, Error>
Add the cap for logistic growth.
Errors
Returns an error if the lengths of ds and cap are not equal.
Sourcepub fn with_floor(self, floor: Vec<f64>) -> Result<Self, Error>
pub fn with_floor(self, floor: Vec<f64>) -> Result<Self, Error>
Add the floor for logistic growth.
Errors
Returns an error if the lengths of ds and floor are not equal.