Predictions

Struct Predictions 

pub struct Predictions {
    pub ds: Vec<TimestampSeconds>,
    pub yhat: FeaturePrediction,
    pub trend: FeaturePrediction,
    pub cap: Option<Vec<f64>>,
    pub floor: Option<Vec<f64>>,
    pub additive: FeaturePrediction,
    pub multiplicative: FeaturePrediction,
    pub holidays: HashMap<String, FeaturePrediction>,
    pub seasonalities: HashMap<String, FeaturePrediction>,
    pub regressors: HashMap<String, FeaturePrediction>,
}
Predictions from a Prophet model.

The yhat field contains the forecasts for the input time series. All other fields contain individual components of the model which contribute towards the final yhat estimate.

Certain fields (such as cap and floor) may be None if the model did not use them (e.g. the model was not configured to use logistic trend).

Fields

ds: Vec<TimestampSeconds>

The timestamps of the forecasts.

yhat: FeaturePrediction

Forecasts of the input time series y.

trend: FeaturePrediction

The trend contribution at each time point.

cap: Option<Vec<f64>>

The cap for the logistic growth.

Will only be Some if the model used GrowthType::Logistic.

floor: Option<Vec<f64>>

The floor for the logistic growth.

Will only be Some if the model used GrowthType::Logistic and the floor was provided in the input data.

additive: FeaturePrediction

The combined combination of all additive components.

This includes seasonalities, holidays and regressors if their mode was configured to be FeatureMode::Additive.

multiplicative: FeaturePrediction

The combined combination of all multiplicative components.

This includes seasonalities, holidays and regressors if their mode was configured to be FeatureMode::Multiplicative.

holidays: HashMap<String, FeaturePrediction>

Mapping from holiday name to that holiday’s contribution.

seasonalities: HashMap<String, FeaturePrediction>

Mapping from seasonality name to that seasonality’s contribution.

regressors: HashMap<String, FeaturePrediction>

Mapping from regressor name to that regressor’s contribution.