pub struct Prophet<O> { /* private fields */ }Expand description
The Prophet time series forecasting model.
Implementations
Sourceimpl<O> Prophet<O>
impl<O> Prophet<O>
Sourcepub fn new(opts: ProphetOptions, optimizer: O) -> Self
pub fn new(opts: ProphetOptions, optimizer: O) -> Self
Create a new Prophet model with the given options and optimizer.
Sourcepub fn add_seasonality(
&mut self,
name: String,
seasonality: Seasonality,
) -> Result<&mut Self, Error>
pub fn add_seasonality( &mut self, name: String, seasonality: Seasonality, ) -> Result<&mut Self, Error>
Add a custom seasonality to the model.
Sourcepub fn add_regressor(&mut self, name: String, regressor: Regressor) -> &mut Self
pub fn add_regressor(&mut self, name: String, regressor: Regressor) -> &mut Self
Add a regressor to the model.
Sourcepub fn predict(
&self,
data: impl Into<Option<PredictionData>>,
) -> Result<Predictions, Error>
pub fn predict( &self, data: impl Into<Option<PredictionData>>, ) -> Result<Predictions, Error>
Sourcepub fn make_future_dataframe(
&self,
horizon: NonZeroU32,
include_history: IncludeHistory,
) -> Result<PredictionData, Error>
pub fn make_future_dataframe( &self, horizon: NonZeroU32, include_history: IncludeHistory, ) -> Result<PredictionData, Error>
Sourcepub fn opts(&self) -> &ProphetOptions
pub fn opts(&self) -> &ProphetOptions
Get a reference to the Prophet options.
Sourcepub fn opts_mut(&mut self) -> &mut ProphetOptions
pub fn opts_mut(&mut self) -> &mut ProphetOptions
Get a mutable reference to the Prophet options.
Sourcepub fn set_interval_width(&mut self, interval_width: IntervalWidth)
pub fn set_interval_width(&mut self, interval_width: IntervalWidth)
Set the width of the uncertainty intervals.
The interval width does not affect training, only predictions, so this can be called after fitting the model to obtain predictions with different levels of uncertainty.
Sourceimpl<O: Optimizer + 'static> Prophet<O>
impl<O: Optimizer + 'static> Prophet<O>
Sourcepub fn into_forecaster(
self,
data: TrainingData,
optimize_opts: OptimizeOpts,
) -> ProphetForecaster
pub fn into_forecaster( self, data: TrainingData, optimize_opts: OptimizeOpts, ) -> ProphetForecaster
Create a new ProphetForecaster from this Prophet model.
This requires the data and optimize options to be provided and sets up
a ProphetForecaster ready to be used with the augurs_forecaster crate.