pub struct TrainingData { /* private fields */ }Expand description
The data needed to train a Prophet model.
Create a TrainingData object with the new method, which
takes a vector of dates and a vector of values.
Optionally, you can add seasonality conditions, regressors, floor and cap columns.
Implementations
Sourceimpl TrainingData
impl TrainingData